@@ -1,5 +1,6 @@
 # coding=utf-8
-from __future__ import absolute_import, print_function, division
+from __future__ import absolute_import, division, print_function
+
 from pkgutil import extend_path
 
 __path__ = extend_path(__path__, __name__)
