@@ -7,7 +7,6 @@ import functools
 import hashlib
 import logging
 import re
-import sys
 import time
 import unicodedata
 from datetime import datetime
@@ -16,43 +15,12 @@ from math import ceil
 import pytz
 import six
 from babel.dates import LOCALTZ
-from flask import current_app, request
+from flask import request
 from six import text_type
 from werkzeug.local import LocalProxy
 
-try:
-    import ipdb as pdb
-except ImportError:
-    import pdb
 
-
-def pdb_on_error(fn):
-    """Decorator to trigger (i)pdb on exception inside decorated function.
-
-    Active only in DEBUG mode. Useful to debug POST only views for
-    example.
-    """
-
-    @functools.wraps(fn)
-    def decorator(*args, **kwargs):
-        try:
-            return fn(*args, **kwargs)
-        except BaseException:
-            if current_app and current_app.debug:
-                type_, value, tb = sys.exc_info()
-                if tb.tb_next is not None:
-                    # error has happened inside decorated function, remove us from top
-                    # stack: better readability in logs, accurate label in
-                    # sentry
-                    tb = tb.tb_next
-
-                pdb.post_mortem(tb)
-            raise
-
-    return decorator
-
-
-def noproxy(obj):
+def unwrap(obj):
     """Unwrap obj from werkzeug.local.LocalProxy if needed.
 
     This is required if one want to test `isinstance(obj, SomeClass)`.
@@ -62,6 +30,10 @@ def noproxy(obj):
     return obj
 
 
+# TODO: remove later
+noproxy = unwrap
+
+
 def fqcn(cls):
     """Fully Qualified Class Name."""
     return text_type(cls.__module__ + "." + cls.__name__)
