@@ -4,4 +4,4 @@ from __future__ import absolute_import, division, print_function
 from .models import ActivityEntry
 from .service import ActivityService
 
-__all__ = ['ActivityEntry', 'ActivityService']
+__all__ = ["ActivityEntry", "ActivityService"]
