@@ -5,4 +5,4 @@ from __future__ import absolute_import, division, print_function
 from .schema import indexable_role
 from .service import service
 
-__all__ = ['service', 'indexable_role']
+__all__ = ["service", "indexable_role"]
