@@ -16,6 +16,7 @@ from __future__ import absolute_import, division, print_function, \
 import logging
 from inspect import isclass
 from pathlib import Path
+from typing import Set
 
 import sqlalchemy as sa
 import whoosh.query as wq
@@ -26,12 +27,9 @@ from flask_login import current_user
 from six import text_type
 from sqlalchemy import event
 from sqlalchemy.orm.session import Session
-from whoosh.analysis import CharsetFilter, StemmingAnalyzer
-from whoosh.collectors import WrappingCollector
 from whoosh.filedb.filestore import FileStorage, RamStorage
 from whoosh.index import FileIndex
 from whoosh.qparser import DisMaxParser
-from whoosh.support.charset import accent_map
 from whoosh.writing import CLEAR, AsyncWriter
 
 from abilian.core import signals
@@ -48,28 +46,9 @@ from .adapter import SAAdapter
 from .schema import DefaultSearchSchema, indexable_role
 
 logger = logging.getLogger(__name__)
-_TEXT_ANALYZER = StemmingAnalyzer() | CharsetFilter(accent_map)
 
 _pending_indexation_attr = "abilian_pending_indexation"
 
-# as of whoosh 2.5.7, a method is missing on WrappingCollector. See
-# https://bitbucket.org/mchaput/whoosh/issue/394/error-when-searching-with-groupedby-and
-_PATCHED = False
-
-if not _PATCHED:
-
-    def wrapping_collector_remove(self, global_docnum):
-        return self.child.remove(global_docnum)
-
-    from abilian.core.logging import patch_logger
-
-    patch_logger.info(WrappingCollector.remove)
-    WrappingCollector.remove = wrapping_collector_remove
-    _PATCHED = True
-    del patch_logger
-    del wrapping_collector_remove
-# END PATCH
-
 
 def url_for_hit(hit, default="#"):
     """Helper for building URLs from results."""
@@ -91,18 +70,11 @@ def fqcn(cls):
 
 
 class IndexServiceState(ServiceState):
-    whoosh_base = None
-    indexes = None
-    indexed_classes = None
-    indexed_fqcn = None
-    search_filter_funcs = None
-    value_provider_funcs = None
-    url_for_hit = None
-
     def __init__(self, *args, **kwargs):
         ServiceState.__init__(self, *args, **kwargs)
+        self.whoosh_base = None
         self.indexes = {}
-        self.indexed_classes = set()
+        self.indexed_classes = set()  # type: Set[type]
         self.indexed_fqcn = set()
         self.search_filter_funcs = []
         self.value_provider_funcs = []
@@ -127,13 +99,12 @@ class WhooshIndexService(Service):
     name = "indexing"
     AppStateClass = IndexServiceState
 
-    _listening = False
-
     def __init__(self, *args, **kwargs):
         Service.__init__(self, *args, **kwargs)
         self.adapters_cls = [SAAdapter]
         self.adapted = {}
         self.schemas = {"default": DefaultSearchSchema()}
+        self._listening = False
 
     def init_app(self, app):
         Service.init_app(self, app)
@@ -185,7 +156,7 @@ class WhooshIndexService(Service):
     def clear_update_queue(self, app=None):
         self.app_state.to_update = []
 
-    def start(self):
+    def start(self, **kw):
         Service.start(self)
         self.register_classes()
         self.init_indexes()
@@ -224,9 +195,9 @@ class WhooshIndexService(Service):
             writer = AsyncWriter(idx)
             writer.commit(merge=True, optimize=True, mergetype=CLEAR)
 
-        state.indexes = {}
-        state.indexed_classes = set()
-        state.indexed_fqcn = set()
+        state.indexes.clear()
+        state.indexed_classes.clear()
+        state.indexed_fqcn.clear()
         self.clear_update_queue()
 
         if self.running:
@@ -243,7 +214,7 @@ class WhooshIndexService(Service):
         """
         config = current_app.config.get("SEARCH_DEFAULT_BOOSTS")
         if not config:
-            config = dict(name=1.5, name_prefix=1.3, description=1.3, text=1.0)
+            config = {"name": 1.5, "name_prefix": 1.3, "description": 1.3, "text": 1.0}
             return config
 
     def searchable_object_types(self):
@@ -463,7 +434,7 @@ class WhooshIndexService(Service):
                 items.append((op, model_name, getattr(obj, primary_field), {}))
 
         if items:
-            index_update.apply_async(kwargs=dict(index="default", items=items))
+            index_update.apply_async(kwargs={"index": "default", "items": items})
         self.clear_update_queue()
 
     def get_document(self, obj, adapter=None):
