@@ -3,6 +3,8 @@
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
+from typing import Text
+
 from six import iteritems
 
 from abilian.core.extensions import db
@@ -15,7 +17,7 @@ class SettingsService(Service):
     name = "settings"
 
     def namespace(self, name):
-        # type: (unicode) -> SettingsNamespace
+        # type: (Text) -> SettingsNamespace
         return SettingsNamespace(name, self)
 
     def keys(self, prefix=None):
