@@ -3,4 +3,4 @@ from __future__ import absolute_import, division, print_function
 
 from .service import viewtracker
 
-__all__ = ['viewtracker']
+__all__ = ["viewtracker"]
