@@ -5,4 +5,4 @@ from __future__ import absolute_import, division, print_function
 from .models import Vocabulary
 from .service import get_vocabulary, vocabularies
 
-__all__ = ['vocabularies', 'get_vocabulary', 'Vocabulary']
+__all__ = ["vocabularies", "get_vocabulary", "Vocabulary"]
