@@ -1,10 +1,9 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function, division
+""""""
+from __future__ import absolute_import, division, print_function
 
-from .forms import AttachmentForm  # noqa
 from .extension import AttachmentExtension, AttachmentsManager
+from .forms import AttachmentForm  # noqa
 
 
 def register_plugin(app):
