@@ -12,14 +12,13 @@ import bleach
 import dateutil.parser
 import flask_babel as babel
 from babel.dates import DateTimePattern, format_timedelta, parse_pattern
+from deprecated import deprecated
 from flask import Flask
 from jinja2 import Markup, escape, evalcontextfilter
 from pytz import utc
 from six import text_type
 from werkzeug.routing import BuildError
 
-from abilian.web.decorators import deprecated
-
 from ..core.util import local_dt, slugify, utc_dt
 from .util import url_for
 
