@@ -12,7 +12,7 @@ import logging
 import re
 from collections import namedtuple
 from datetime import datetime
-from typing import Any, Dict, Text
+from typing import Any, Dict, Optional, Text
 
 import bleach
 import sqlalchemy as sa
@@ -24,7 +24,6 @@ from flask_babel import format_date, format_datetime, format_number, get_locale
 from flask_login import current_user
 from flask_wtf.file import FileField
 from six import string_types, text_type
-from six.moves import filter
 from six.moves.urllib import parse
 from wtforms.widgets import HTMLString, Input
 from wtforms.widgets import PasswordInput as BasePasswordInput
@@ -133,12 +132,22 @@ class Column(object):
             setattr(self, k, w)
 
 
+class View(object):
+    options = {}  # type: Dict[Text, Any]
+
+    def get_templates(self, specific_template_name, default_template):
+        specific_template = self.options.get(specific_template_name)
+        if specific_template:
+            return [specific_template, default_template]
+        else:
+            return [default_template]
+
+
 # TODO: rewrite
-class BaseTableView(object):
+class BaseTableView(View):
     show_controls = False
     show_search = None
     paginate = False
-    options = {}  # type: Dict[Text, Any]
 
     def __init__(self, columns, options=None):
         if self.show_search is None:
@@ -160,7 +169,7 @@ class BaseTableView(object):
         default_width = "{:2.0f}%".format(0.99 / len(columns) * 100)
         for col in columns:
             if isinstance(col, string_types):
-                col = dict(name=col, width=default_width)
+                col = {"name": col, "width": default_width}
             assert isinstance(col, dict)
             col.setdefault("width", default_width)
             col.setdefault("sorting", ("asc", "desc"))
@@ -209,11 +218,9 @@ class BaseTableView(object):
         for entity in entities:
             table.append(self.render_line(entity))
 
-        template = filter(
-            bool, (self.options.get("template"), "widgets/render_table.html")
-        )
+        templates = self.get_templates("template", "widgets/render_table.html")
         return Markup(
-            render_template(template, table=table, js=Markup(js), view=self, **kwargs)
+            render_template(templates, table=table, js=Markup(js), view=self, **kwargs)
         )
 
     def render_line(self, entity):
@@ -288,7 +295,7 @@ class RelatedTableView(BaseTableView):
     paginate = False
 
 
-class AjaxMainTableView(object):
+class AjaxMainTableView(View):
     """Variant of the MainTableView that gets content from AJAX requests.
 
     TODO: refactor all of this (currently code is copy/pasted!).
@@ -296,7 +303,6 @@ class AjaxMainTableView(object):
 
     show_controls = False
     paginate = True
-    options = {}  # type: Dict[Text, Any]
 
     def __init__(
         self, columns, ajax_source, search_criterions=(), name=None, options=None
@@ -315,7 +321,7 @@ class AjaxMainTableView(object):
         default_width = 0.99 / len(columns)
         for col in columns:
             if isinstance(col, str):
-                col = dict(name=col, width=default_width)
+                col = {"name": col, "width": default_width}
             assert isinstance(col, dict)
             if "label" not in col:
                 col["label"] = labelize(col["name"])
@@ -363,18 +369,18 @@ class AjaxMainTableView(object):
             datatable_options["aaSorting"] = self.options.get("aaSorting")
 
         advanced_search_filters = []
-        for c in self.search_criterions:
-            if not c.has_form_filter:
+        for criterion in self.search_criterions:
+            if not criterion.has_form_filter:
                 continue
-            d = dict(
-                name=c.name,
-                label=text_type(c.label),
-                type=c.form_filter_type,
-                args=c.form_filter_args,
-                unset=c.form_unset_value,
-            )
-            if c.has_form_default_value:
-                d["defaultValue"] = c.form_default_value
+            d = {
+                "name": criterion.name,
+                "label": text_type(criterion.label),
+                "type": criterion.form_filter_type,
+                "args": criterion.form_filter_args,
+                "unset": criterion.form_unset_value,
+            }
+            if criterion.has_form_default_value:
+                d["defaultValue"] = criterion.form_default_value
 
             advanced_search_filters.append(d)
 
@@ -443,7 +449,7 @@ class AjaxMainTableView(object):
 #
 # Single object view
 #
-class SingleView(object):
+class SingleView(View):
     """View on a single object."""
 
     def __init__(self, form, *panels, **options):
@@ -486,10 +492,7 @@ class SingleView(object):
             if data:
                 panels.append((panel, data))
 
-        template = filter(
-            bool, (self.options.get("view_template"), "widgets/render_single.html")
-        )
-
+        templates = self.get_templates("view_template", "widgets/render_single.html")
         ctx = {
             "view": self,
             "related_views": related_views,
@@ -497,7 +500,7 @@ class SingleView(object):
             "panels": panels,
             "form": form,
         }
-        return Markup(render_template(template, **ctx))
+        return Markup(render_template(templates, **ctx))
 
     def render_form(self, form, for_new=False, has_save_and_add_new=False):
         # Client-side rules for jQuery.validate
@@ -516,9 +519,7 @@ class SingleView(object):
         else:
             rules = None
 
-        template = filter(
-            bool, (self.options.get("edit_template"), "widgets/render_for_edit.html")
-        )
+        templates = self.get_templates("edit_template", "widgets/render_for_edit.html")
         ctx = {
             "view": self,
             "form": form,
@@ -526,7 +527,7 @@ class SingleView(object):
             "has_save_and_add_new": has_save_and_add_new,
             "rules": rules,
         }
-        return Markup(render_template(template, **ctx))
+        return Markup(render_template(templates, **ctx))
 
     def label_for(self, field, mapper, name):
         label = field.label
@@ -641,8 +642,8 @@ class TextInput(wtforms.widgets.TextInput):
     :class:`abilian.web.action.Icon`.
     """
 
-    pre_icon = None
-    post_icon = None
+    pre_icon = None  # type: Optional[Text]
+    post_icon = None  # type: Optional[Text]
 
     def __init__(self, input_type=None, pre_icon=None, post_icon=None, *args, **kwargs):
         super(TextInput, self).__init__(input_type, *args, **kwargs)
@@ -1555,7 +1556,7 @@ class Select2Ajax(object):
             if callable(values_builder)
             else lambda data: [{"id": o.id, "text": o.name} for o in data if o]
         )
-        self.s2_params = dict(multiple=self.multiple)
+        self.s2_params = {"multiple": self.multiple}
 
         if format_result:
             self.s2_params["formatResult"] = format_result
