@@ -10,11 +10,10 @@ from flask import make_response
 
 
 def nocache(view):
-
     @wraps(view)
     def _nocache(*args, **kwargs):
         resp = make_response(view(*args, **kwargs))
-        resp.headers['Cache-Control'] = 'no-cache'
+        resp.headers["Cache-Control"] = "no-cache"
         return resp
 
     return _nocache
