@@ -16,7 +16,7 @@ from abilian.web.views import Registry, default_view
 
 
 class RegEntity(Entity):
-    name = sa.Column(sa.Unicode, default='')
+    name = sa.Column(sa.Unicode, default="")
 
 
 class NonEntity(object):
@@ -30,18 +30,18 @@ def registry(app):
 
 
 def test_register_class(app, registry):
-    registry.register(RegEntity, lambda ignored: '')
+    registry.register(RegEntity, lambda ignored: "")
     assert RegEntity.entity_type in registry._map
 
 
 def test_register_instance(app, registry):
     obj = RegEntity()
-    registry.register(obj, lambda ignored: '')
+    registry.register(obj, lambda ignored: "")
     assert RegEntity.entity_type in registry._map
 
 
 def test_custom_url_func(app, registry):
-    name = 'obj'
+    name = "obj"
     obj = RegEntity(id=1, name=name)
 
     def custom_url(obj, obj_type, obj_id):
@@ -51,32 +51,31 @@ def test_custom_url_func(app, registry):
     assert registry.url_for(obj) == name
 
     def url_from_type_and_id(obj, obj_type, obj_id):
-        return '{}:{}'.format(obj_type, obj_id)
+        return "{}:{}".format(obj_type, obj_id)
 
     registry.register(obj, url_from_type_and_id)
-    assert registry.url_for(obj) == 'test_registry.RegEntity:1'
+    assert registry.url_for(obj) == "test_registry.RegEntity:1"
 
 
 def test_default_url_func(app, registry, test_request_context):
     obj = RegEntity(id=1)
 
-    @app.route(
-        '/regentities_path/<int:object_id>/view',
-        endpoint='regentity.view',
-    )
+    @app.route("/regentities_path/<int:object_id>/view", endpoint="regentity.view")
     def dummy_default_view(object_id):
         pass
 
-    assert registry.url_for(obj) == '/regentities_path/1/view'
-    assert registry.url_for(obj, _external=True) == \
-        'http://localhost/regentities_path/1/view'
+    assert registry.url_for(obj) == "/regentities_path/1/view"
+    assert (
+        registry.url_for(obj, _external=True)
+        == "http://localhost.localdomain/regentities_path/1/view"
+    )
 
 
 def test_default_view_decorator(app, registry, test_request_context):
-    bp = Blueprint('registry', __name__, url_prefix='/blueprint')
+    bp = Blueprint("registry", __name__, url_prefix="/blueprint")
 
     @default_view(bp, RegEntity)
-    @bp.route('/<int:object_id>')
+    @bp.route("/<int:object_id>")
     def view(object_id):
         pass
 
@@ -88,6 +87,8 @@ def test_default_view_decorator(app, registry, test_request_context):
     # blueprint registered: default view is set
     app.register_blueprint(bp)
 
-    assert registry.url_for(obj) == '/blueprint/1'
-    assert registry.url_for(obj, _external=True) == \
-        'http://localhost/blueprint/1'
+    assert registry.url_for(obj) == "/blueprint/1"
+    assert (
+        registry.url_for(obj, _external=True)
+        == "http://localhost.localdomain/blueprint/1"
+    )
